

ObjectData
===================================

.. currentmodule:: pyvo.nameresolver.sesame

.. autoclass:: ObjectData
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~ObjectData.aliases
      ~ObjectData.fromcache
      ~ObjectData.metadata
      ~ObjectData.oname
      ~ObjectData.pos
      ~ObjectData.resolver_name
      ~ObjectData.sexapos
      ~ObjectData.success

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~ObjectData.get
      ~ObjectData.getpos
      ~ObjectData.keys

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: aliases
   .. autoattribute:: fromcache
   .. autoattribute:: metadata
   .. autoattribute:: oname
   .. autoattribute:: pos
   .. autoattribute:: resolver_name
   .. autoattribute:: sexapos
   .. autoattribute:: success

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: get
   .. automethod:: getpos
   .. automethod:: keys

   
   